'use strict';

scheduler.config(['$routeProvider', function($routeProvider) {
  $routeProvider.when('/calendar', {
    templateUrl: '/app/scheduler/views/calendar/calendar.html',
    controller: 'CalendarCtrl'
  });
}])

.controller('CalendarCtrl', ['$scope', 'moment', 'shared', '$http',
function($scope, moment, shared, $http) {
  $scope.CurrentDate = new Date();

  var startOfMonth = function(year, month) {
    return moment({
      year: year,
      month: month - 1
    });
  };

  $scope.startOfMonth = function() { return startOfMonth($scope.year, $scope.month); };

  /**
   * Get all the days in the month, grouped into week arrays; used
   * for the view for generating table rows.
   */
  var updateWeeks = function() {
    var monthStart = startOfMonth($scope.year, $scope.month);

    var day = monthStart.clone().startOf('week');
    var lastDay = monthStart.clone().endOf('month');

    var weeks = [];
    while (day.isBefore(lastDay) || day.isSame(lastDay)) {
      var week = [];
      for (var i = 0; i < 7; i++) {
        week.push(day.clone());
        day.add('days', 1);
      }
      weeks.push(week);
    }

    $scope.weeks = weeks;
  }

  /**
   * Get the schedule for a particular date
   */
  $scope.getSchedule = function(date) {
    if (!$scope.data.calendar) return {};

    if (date.month() != $scope.month - 1)
      return;

    var dateStr = date.format('YYYY-MM-DD');
    if ($scope.data.calendar[dateStr]) {
      return $scope.data.schedules[$scope.data.calendar[dateStr]];
    }
    return {};
  };

  $scope.setSchedule = function(date, scheduleId) {
    if (date.month() != $scope.month - 1)
      return;

    if (scheduleId < 0)
      return;

    var dateStr = date.format('YYYY-MM-DD');
    if (scheduleId > 0) {
      $scope.data.calendar[dateStr] = scheduleId;
    } else if (scheduleId == 0) {
      delete $scope.data.calendar[dateStr];
    }
    updateWeeks();
  };

  var checkMonth = function() {
    if ($scope.month == 0) {
      $scope.month = 12;
      $scope.year -= 1;
    } else if ($scope.month == 13) {
      $scope.month = 1;
      $scope.year += 1;
    }
    updateWeeks();
  }

  // Events
  $scope.goToday = function() {
	$http.get("/control/sched-start.lua?t=get_time")
		.success(function(response){
			var devTime = response;
			var newTime = devTime.slice(0, -10) + devTime.slice(-6);

			var today = new Date(newTime);
			$scope.month = today.getMonth() + 1;
			$scope.year = today.getFullYear();
			checkMonth();
		});
  };

  $scope.goPrevMonth = function() {
    $scope.month -= 1;
    checkMonth();
  };

  $scope.goNextMonth = function() {
    $scope.month += 1;
    checkMonth();
  };

  $scope.markAll = function(scheduleId) {
    var date = startOfMonth($scope.year, $scope.month);
    var end = date.clone().endOf('month');

    while (date.isBefore(end) || date.isSame(end)) {
      var dateStr = date.format('YYYY-MM-DD');
      if (scheduleId == '0') {
        delete $scope.data.calendar[dateStr];
      } else if (scheduleId != '-1') {
        $scope.data.calendar[dateStr] = scheduleId;
      }
      date.add('days', 1);
    }
    updateWeeks();
  };

  $scope.markAllWeekdays = function(scheduleId) {
    var date = startOfMonth($scope.year, $scope.month);
    var end = date.clone().endOf('month');

    while (date.isBefore(end) || date.isSame(end)) {
      var day = date.day();
      if (day >= 1 && day <= 5) {
        var dateStr = date.format('YYYY-MM-DD');
        if (scheduleId == '0') {
          delete $scope.data.calendar[dateStr];
        } else if (scheduleId != '-1') {
          $scope.data.calendar[dateStr] = scheduleId;
        }
      }
      date.add('days', 1);
    }
    updateWeeks();
  };

  $scope.getScheduleColour = function(scheduleId) {
    return $scope.data.schedules[scheduleId].color;
  }

  shared.activateMenu(0);
  var now = new Date();
  $scope.month = now.getMonth() + 1;
  $scope.year = now.getFullYear();
  updateWeeks();
  $scope.typePaintbrush = "-1";

  // Common between views data
  shared.fetch(function(data) {
    $scope.data = data;
  });
}]);
