var scheduler = angular.module('algo.scheduler', ['ngRoute'])

// Shared with other schedule pages, including schedules
.directive('schedulerMenu', function() {
  return {
    controller: 'SchedulerMenuCtrl',
    templateUrl: '/app/scheduler/views/partials/scheduler_menu.html'
  };
})

.controller('SchedulerMenuCtrl', ['$scope', '$location', 'shared', '$interval', '$http',
  function($scope, $location, shared, $interval, $http) {

  // Check if time is in sync
  var checkTime = function () {
    $http.get("/control/sched-start.lua?t=get_epoch")
    .success(function(response){
      var devEpoch = response;
      var browserTime = new Date().getTime();
      var browserEpoch = browserTime/1000;

      if (Math.abs(browserEpoch - devEpoch) < 60){
        $scope.epochDifferent = false;
      } else {
        $scope.epochDifferent = true;
      }
    });
  };

  // Clock Configurations
  // Using system as the user might come to the page before NTP is compelete
  $http.get("/control/sched-start.lua?t=get_time")
  .success(function(response){
    var devTime = response;
    $scope.deviceTime = new Date(devTime);
    checkTime();
  });

  // Ticking Clock
  $interval(function () {
    $scope.deviceTime.setSeconds($scope.deviceTime.getSeconds() + 1);
  }, 1000);

  // Saves the settings by making a server call
  $scope.persist = function() {
    shared.persist(function validateCallback(messages) {
      $scope.messages = messages;
      $scope.success = false;
    })
    .success(function(data, status, headers, config) {
      $scope.messages = ['Data saved successfully'];
      $scope.success = true;

      if (headers.location) {
        location.href = headers.location;
      } else if (status == 302) {
        location.href = '/index';
      }
    })
    .error(function(data, status, headerGetter, config) {
      var headers = headerGetter();

      $scope.messages = ['We encountered an error while saving your schedule settings; please refresh the page and try again.'];
      $scope.success = false;
    });
  };

  $scope.isActive = function(route) {
    return route === $location.path();
  };
}])

.directive('notification', function() {
  return {
    templateUrl: '/app/scheduler/views/partials/notification.html'
  };
});
