'use strict';

scheduler.config(['$routeProvider', function($routeProvider) {
  $routeProvider.when('/schedules', {
    templateUrl: '/app/scheduler/views/schedules/schedules.html',
    controller: 'SchedulesPageCtrl'
  });
}])

.controller('SchedulesPageCtrl', ['$scope', 'moment', 'shared',
function($scope, moment, shared) {
  /**
   * Error and message handling for the form to add something
   */
  var messages = function(success, messages) {
    $scope.success = success;
    $scope.messages = messages;
  };

  /**
   * Set the schedule being edited in the form.
   */
  $scope.setCurSchedule = function(id) {
    $scope.curSchedule = $scope.data.schedules[id];
  };

  $scope.addSchedule = function() {
    // Find an empty ID, and assign it
    var maxId = 0;
    $.each($scope.data.schedules, function(id, schedule) {
      maxId = Math.max(maxId, id);
    });

    var newId = maxId + 1;
    $scope.data.schedules[newId] = {
      id: newId,
      name: '',
      color: '#EEEEEE'
    };
    $scope.setCurSchedule(newId);
    $scope.addEvent();
  };

  $scope.removeSchedule = function(id) {
    delete $scope.data.schedules[id];
    $scope.curSchedule.events = null;
  };

  $scope.copySchedule = function(id) {
    var newSched;
    var newName;
    var oldSched;

    oldSched = $scope.data.schedules[id];

    var maxId = 0;
    $.each($scope.data.schedules, function(id, schedule) {
      maxId = Math.max(maxId, id);
    });

    /* Give the copied schedule a unique name */
    var scheduleNames = {};
    var repeat = 1;
    newName = oldSched.name;
    while (repeat) {
      repeat = 0;
      $.each($scope.data.schedules, function(id, schedule) {
        scheduleNames[schedule.name] = true;
        if (newName in scheduleNames) {
          newName = newName + 'copy';
          repeat = 1;
        }
      });
    }

    var newId = maxId + 1;
    $scope.data.schedules[newId] = {
      id: newId,
      name: newName,
      color: oldSched.color
    };

    newSched = $scope.data.schedules[newId];
    newSched.events = [];

    var events = oldSched.events;
    for (var i = 0; i < events.length; i++) {
      newSched.events.push(angular.copy(events[i]));
    }
  };

  /**
   * Add a new event to the current schedule.
   */
  $scope.addEvent = function(event) {
    event = event ?
      angular.copy(event) : {time: "hh:mm:ss", audio: audioLocalList[0],
                             zone: 1, group: 1};

    if (!$scope.curSchedule.events) {
      $scope.curSchedule.events = [];
    }
    $scope.curSchedule.events.push(event);
  };

  $scope.removeEvent = function(event) {
    var events = $scope.curSchedule.events;
    for (var i = 0; i < events.length; i++) {
      if (events[i] == event) {
        events.splice(i, 1);
        break;
      }
    }
  };

  $scope.sortEvents = function() {
    $scope.curSchedule.events.sort(function(a, b) {
      return eventTime(a) - eventTime(b);
    });
  };

  /**
   * Used as a sorting function for times.
   */
  var eventTime = function(event) {
    if (!event.time) {
      return Number.MAX_SAFE_INTEGER;
    }
    return shared.makeMoment(event.time).unix();
  };

  /**
   * Use to parse angular string values to int, such as array keys.
   */
  $scope.parseInt = function(num) {
        return parseInt(num, 10);
  };

  // INITIALIZATION
  shared.activateMenu(1);

  shared.fetch(function(data) {
    $scope.data = data;
    var firstSchedule;
    if ($.isEmptyObject(data.schedules)) {
      $scope.addSchedule();
    }
    $.each(data.schedules, function(id, schedule) {
      firstSchedule = schedule;
      return false;
    });

    $scope.curSchedule = firstSchedule;
  });
  $scope.audioLocal = audioLocalList;
  $scope.nZones = pageZones;
  $scope.nGroups = ppaGroups;

  $scope.rtpZone = {};
  $scope.rtpZone[0] = 'None';
  for (var i = 1; i <= pageZones; i++) {
    $scope.rtpZone[i] = i;
  }
  $scope.rtpZone[7] = 'Music';
  $scope.rtpZone[8] = 'All Call';
  $scope.rtpZone[9] = 'Priority Call';

  $scope.ppaGroup = {};
  $scope.ppaGroup[0] = 'None';
  for (var i = 1; i <= ppaGroups; i++) {
    $scope.ppaGroup[i] = i;
  }

  $scope.rtpActive = rtpActive;
  $scope.ppaActive = ppaActive;
}]);
